You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by va...@apache.org on 2017/03/07 22:07:13 UTC

[1/4] couch-replicator commit: updated refs/heads/master to 0e407de

Repository: couchdb-couch-replicator
Updated Branches:
  refs/heads/master 50a88baaf -> 0e407defe


Remove unused mp_parse_doc function from replicator

It was left accidentally when merging Cloudant's dbcore work.

COUCHDB-2992


Project: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/commit/30915e33
Tree: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/tree/30915e33
Diff: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/diff/30915e33

Branch: refs/heads/master
Commit: 30915e3309fb30c2164e668d33dbd393e77925c0
Parents: 50a88ba
Author: Nick Vatamaniuc <va...@apache.org>
Authored: Tue Mar 7 14:38:29 2017 -0500
Committer: Nick Vatamaniuc <va...@apache.org>
Committed: Tue Mar 7 14:38:29 2017 -0500

----------------------------------------------------------------------
 src/couch_replicator_utils.erl | 30 ------------------------------
 1 file changed, 30 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/blob/30915e33/src/couch_replicator_utils.erl
----------------------------------------------------------------------
diff --git a/src/couch_replicator_utils.erl b/src/couch_replicator_utils.erl
index 223bac8..e96d52a 100644
--- a/src/couch_replicator_utils.erl
+++ b/src/couch_replicator_utils.erl
@@ -17,7 +17,6 @@
 -export([start_db_compaction_notifier/2, stop_db_compaction_notifier/1]).
 -export([replication_id/2]).
 -export([sum_stats/2, is_deleted/1]).
--export([mp_parse_doc/2]).
 
 -export([handle_db_event/3]).
 
@@ -449,35 +448,6 @@ handle_db_event(_DbName, _Event, Server) ->
 sum_stats(S1, S2) ->
     couch_replicator_stats:sum_stats(S1, S2).
 
-mp_parse_doc({headers, H}, []) ->
-    case couch_util:get_value("content-type", H) of
-    {"application/json", _} ->
-        fun (Next) ->
-            mp_parse_doc(Next, [])
-        end
-    end;
-mp_parse_doc({body, Bytes}, AccBytes) ->
-    fun (Next) ->
-        mp_parse_doc(Next, [Bytes | AccBytes])
-    end;
-mp_parse_doc(body_end, AccBytes) ->
-    receive {get_doc_bytes, Ref, From} ->
-        From ! {doc_bytes, Ref, lists:reverse(AccBytes)}
-    end,
-    fun mp_parse_atts/1.
-
-mp_parse_atts(eof) ->
-    ok;
-mp_parse_atts({headers, _H}) ->
-    fun mp_parse_atts/1;
-mp_parse_atts({body, Bytes}) ->
-    receive {get_bytes, Ref, From} ->
-        From ! {bytes, Ref, Bytes}
-    end,
-    fun mp_parse_atts/1;
-mp_parse_atts(body_end) ->
-    fun mp_parse_atts/1.
-
 is_deleted(Change) ->
     case couch_util:get_value(<<"deleted">>, Change) of
     undefined ->


[3/4] couch-replicator commit: updated refs/heads/master to 0e407de

Posted by va...@apache.org.
Fix unit test after renaming max_document_size config parameter

`couchdb.max_document_size` was renamed to `httpd.max_http_request_size`

The unit tests was testing how replicator behaves when faced with reduced
request size configuration on the target.

COUCHDB-2992


Project: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/commit/64958096
Tree: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/tree/64958096
Diff: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/diff/64958096

Branch: refs/heads/master
Commit: 64958096d4f9a940c01cbc472da5265f349c9545
Parents: 1166759
Author: Nick Vatamaniuc <va...@apache.org>
Authored: Tue Mar 7 16:42:43 2017 -0500
Committer: Nick Vatamaniuc <va...@apache.org>
Committed: Tue Mar 7 16:42:43 2017 -0500

----------------------------------------------------------------------
 test/couch_replicator_small_max_request_size_target.erl | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/blob/64958096/test/couch_replicator_small_max_request_size_target.erl
----------------------------------------------------------------------
diff --git a/test/couch_replicator_small_max_request_size_target.erl b/test/couch_replicator_small_max_request_size_target.erl
index c46619d..b7d9fbe 100644
--- a/test/couch_replicator_small_max_request_size_target.erl
+++ b/test/couch_replicator_small_max_request_size_target.erl
@@ -27,7 +27,7 @@ setup(remote) ->
 
 setup({A, B}) ->
     Ctx = test_util:start_couch([couch_replicator]),
-    config:set("couchdb", "max_document_size", "10000", false),
+    config:set("httpd", "max_http_request_size", "10000", false),
     Source = setup(A),
     Target = setup(B),
     {Ctx, {Source, Target}}.
@@ -49,7 +49,7 @@ teardown(_, {Ctx, {Source, Target}}) ->
 reduce_max_request_size_test_() ->
     Pairs = [{local, remote}, {remote, remote}],
     {
-        "Replicate docs when target has a small max_document_size",
+        "Replicate docs when target has a small max_http_request_size",
         {
             foreachx,
             fun setup/1, fun teardown/2,
@@ -66,8 +66,8 @@ reduce_max_request_size_test_() ->
     }.
 
 
 % Test documents which are below max_document_size but when batched, batch size
 % will be greater than max_document_size. Replicator could automatically split
 % the batch into smaller batches and POST those separately.
 should_replicate_all_docs({From, To}, {_Ctx, {Source, Target}}) ->
     {lists:flatten(io_lib:format("~p -> ~p", [From, To])),


[2/4] couch-replicator commit: updated refs/heads/master to 0e407de

Posted by va...@apache.org.
Merge remote-tracking branch 'cloudant/couchdb-2992-remove-dead-code'

Closes #60


Project: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/commit/11667591
Tree: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/tree/11667591
Diff: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/diff/11667591

Branch: refs/heads/master
Commit: 11667591c1211ef2817945393ec22e0361d900ad
Parents: 50a88ba 30915e3
Author: Nick Vatamaniuc <va...@apache.org>
Authored: Tue Mar 7 14:45:59 2017 -0500
Committer: Nick Vatamaniuc <va...@apache.org>
Committed: Tue Mar 7 14:45:59 2017 -0500

----------------------------------------------------------------------
 src/couch_replicator_utils.erl | 30 ------------------------------
 1 file changed, 30 deletions(-)
----------------------------------------------------------------------



[4/4] couch-replicator commit: updated refs/heads/master to 0e407de

Posted by va...@apache.org.
Merge branch '64229-add-new-request-parameter'

Closes #60


Project: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/commit/0e407def
Tree: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/tree/0e407def
Diff: http://git-wip-us.apache.org/repos/asf/couchdb-couch-replicator/diff/0e407def

Branch: refs/heads/master
Commit: 0e407defeb389bf6f7a9946ef620d14335656826
Parents: 50a88ba 6495809
Author: Nick Vatamaniuc <va...@apache.org>
Authored: Tue Mar 7 17:06:47 2017 -0500
Committer: Nick Vatamaniuc <va...@apache.org>
Committed: Tue Mar 7 17:06:47 2017 -0500

----------------------------------------------------------------------
 src/couch_replicator_utils.erl                  | 30 --------------------
 ...replicator_small_max_request_size_target.erl |  8 +++---
 2 files changed, 4 insertions(+), 34 deletions(-)
----------------------------------------------------------------------
@@ -66,8 +66,8 @@ reduce_max_request_size_test_() ->
 
 
-% Test documents which are below max_document_size but when batched, batch size
-% will be greater than max_document_size. Replicator could automatically split
+% Test documents which are below max_http_request_size but when batched, batch size
+% will be greater than max_http_request_size. Replicator could automatically split
 % the batch into smaller batches and POST those separately.
 should_replicate_all_docs({From, To}, {_Ctx, {Source, Target}}) ->